#import counts and descriptive table
counts_NK2<- read.csv2("counts_NK.csv", row.names = 1)
desc_tab<-read.csv2("Descriptive_Table_NK_2.csv")

library(edgeR)
#create DGElist and filter unexpressed genes
x<- DGEList(counts = counts_NK2, genes = rownames(counts_NK2), group = desc_tab$Group.Day)
keep<-rowSums(cpm(x)>1)>=8
x.1<-x[keep,]
dim(x.1)

x.1<- calcNormFactors(x.1)


batch<- factor(desc_tab$Library.Batch)
day<- factor(desc_tab$Group.Day)
day<- relevel(day, ref = "0")


design<- model.matrix(~batch+day)

x.2<- estimateDisp(x.1, design)
  
qlfit_new<- glmQLFit(x.2, design)

#differential gene expression analysis day 1 vs day 0
DEA_Day1<- glmTreat(qlfit_new, coef=4, lfc=log2(1.2)) 
summary(decideTestsDGE(DEA_Day1))

DEA_Day1<- topTags(DEA_Day1, n=Inf)
write.csv2(DEA_Day1, "DEA_Day1_NK.csv")
#selection of genes in the LIM61.0
LI61.0<-DEA_Day1[c("KLRB1", "CD7", "GPR56", "NKG7", 
                   "KIR2DL2", "KIR2DS4", "KIR2DS5", "KIR2DS2", "KIR2DS3", "S1PR5", "KIR2DS1", "KLRF1", "TGFBR3", "KIR3DL1",
                   "KIR2DL5A", "KIR3DL3", "IL2RB", "KLRK1", "KIR2DL3", "CD96", "KIR2DL1", "CD247", "PVRIG", "TARP"), ]
write.csv2(LI61.0, "LI61.0_NK_day1.csv")

#differential gene expression analysis day 3 vs day 0
DEA_Day3<- glmTreat(qlfit_new, coef=5, lfc=log2(1.2)) 
summary(decideTestsDGE(DEA_Day3))

DEA_Day3<- topTags(DEA_Day3, n=Inf)
write.csv2(DEA_Day3, "DEA_Day3_NK.csv")
#selection of genes in the LIM61.0
LI61.0_D3<-DEA_Day3[c("KLRB1", "CD7", "GPR56", "NKG7", 
                      "KIR2DL2", "KIR2DS4", "KIR2DS5", "KIR2DS2", "KIR2DS3", "S1PR5", "KIR2DS1", "KLRF1", "TGFBR3", "KIR3DL1",
                      "KIR2DL5A", "KIR3DL3", "IL2RB", "KLRK1", "KIR2DL3", "CD96", "KIR2DL1", "CD247", "PVRIG", "TARP"), ]
write.csv2(LI61.0_D3, "LI61.0_NK_day3.csv")

#differential gene expression analysis day 7 vs day 0
DEA_Day7<- glmTreat(qlfit_new, coef=6, lfc=log2(1.2)) 
summary(decideTestsDGE(DEA_Day7))

DEA_Day7<- topTags(DEA_Day7, n=Inf)
write.csv2(DEA_Day7, "DEA_Day7_NK.csv")
#selection of genes in the LIM61.0
LI61.0_D7<-DEA_Day7[c("KLRB1", "CD7", "GPR56", "NKG7", 
                      "KIR2DL2", "KIR2DS4", "KIR2DS5", "KIR2DS2", "KIR2DS3", "S1PR5", "KIR2DS1", "KLRF1", "TGFBR3", "KIR3DL1",
                      "KIR2DL5A", "KIR3DL3", "IL2RB", "KLRK1", "KIR2DL3", "CD96", "KIR2DL1", "CD247", "PVRIG", "TARP"), ]
write.csv2(LI61.0_D7, "LI61.0_NK_day7.csv")

#calculation of zeta scores for each subject
#conversion of counts to cpm and log2 transformation
cpmx.1<-cpm(x.1)  
logs<-log2(cpmx.1+1)
logs<-t(scale(t(logs)))

library(tmod)
data("tmod")

#creation of a storage matrix
modules<-matrix(ncol=ncol(logs), nrow=dim(tmod$MODULES)[1])
rownames(modules)<-tmod$MODULES$ID
colnames(modules)<- colnames(logs)
#creation of a vector which stores the gene info for each module
l<-vector() 

n<-1
while(n<nrow(modules)+1){
  lmod<-logs[rownames(logs) %in% tmod$MODULES2GENES[[n]],]
  if(is.matrix(lmod)){
    modules[n,]<-apply(lmod, 2, mean)
    l[n]<-nrow(lmod)
  }
  print(n)
  n<-n+1
}
names(l)<-rownames(modules)
l
modules

#selection of "LI" modules
LI_modules<-modules[1:346,]
l<-l[1:346]
# drop NA values
LI_modules_complete<-LI_modules[complete.cases(LI_modules),] 

#get zeta scores for each day and calculate enrichment for each subject by subtraction of baseline
write.csv2(LI_modules_complete, "NK_Z_scores.csv")
class(LI_modules_complete)

LI_modules_complete<-as.data.frame(LI_modules_complete)

LI_modules_complete$X315_D1.D0 <- LI_modules_complete$X315_D1 - LI_modules_complete$X315_D0
LI_modules_complete$X316_D1.D0 <- LI_modules_complete$X316_D1 - LI_modules_complete$X316_D0
LI_modules_complete$X110_D1.D0 <- LI_modules_complete$X110_D1 - LI_modules_complete$X110_D0
LI_modules_complete$X116_D1.D0 <- LI_modules_complete$X116_D1 - LI_modules_complete$X116_D0
LI_modules_complete$X128_D1.D0 <- LI_modules_complete$X128_D1 - LI_modules_complete$X128_D0
LI_modules_complete$X302_D1.D0 <- LI_modules_complete$X302_D1 - LI_modules_complete$X302_D0
LI_modules_complete$X130_D1.D0 <- LI_modules_complete$X130_D1 - LI_modules_complete$X130_D0
LI_modules_complete$X324_D1.D0 <- LI_modules_complete$X324_D1 - LI_modules_complete$X324_D0
LI_modules_complete$D1.D0_mean <- rowMeans(LI_modules_complete[,33:40])
LI_modules_D1.DO <- LI_modules_complete[,33:41]
write.csv2(LI_modules_D1.DO, "NK_BTM_enrichment_D1-D0.csv")

LI_modules_complete$X315_D3.D0 <- LI_modules_complete$X315_D3 - LI_modules_complete$X315_D0
LI_modules_complete$X316_D3.D0 <- LI_modules_complete$X316_D3 - LI_modules_complete$X316_D0
LI_modules_complete$X110_D3.D0 <- LI_modules_complete$X110_D3 - LI_modules_complete$X110_D0
LI_modules_complete$X116_D3.D0 <- LI_modules_complete$X116_D3 - LI_modules_complete$X116_D0
LI_modules_complete$X128_D3.D0 <- LI_modules_complete$X128_D3 - LI_modules_complete$X128_D0
LI_modules_complete$X302_D3.D0 <- LI_modules_complete$X302_D3 - LI_modules_complete$X302_D0
LI_modules_complete$X130_D3.D0 <- LI_modules_complete$X130_D3 - LI_modules_complete$X130_D0
LI_modules_complete$X324_D3.D0 <- LI_modules_complete$X324_D3 - LI_modules_complete$X324_D0
LI_modules_complete$D3.D0_mean <- rowMeans(LI_modules_complete[,42:49])
LI_modules_D3.DO <- LI_modules_complete[,42:50]
write.csv2(LI_modules_D3.DO, "NK_BTM_enrichment_D3-D0.csv")

LI_modules_complete$X315_D7.D0 <- LI_modules_complete$X315_D7 - LI_modules_complete$X315_D0
LI_modules_complete$X316_D7.D0 <- LI_modules_complete$X316_D7 - LI_modules_complete$X316_D0
LI_modules_complete$X110_D7.D0 <- LI_modules_complete$X110_D7 - LI_modules_complete$X110_D0
LI_modules_complete$X116_D7.D0 <- LI_modules_complete$X116_D7 - LI_modules_complete$X116_D0
LI_modules_complete$X128_D7.D0 <- LI_modules_complete$X128_D7 - LI_modules_complete$X128_D0
LI_modules_complete$X302_D7.D0 <- LI_modules_complete$X302_D7 - LI_modules_complete$X302_D0
LI_modules_complete$X130_D7.D0 <- LI_modules_complete$X130_D7 - LI_modules_complete$X130_D0
LI_modules_complete$X324_D7.D0 <- LI_modules_complete$X324_D7 - LI_modules_complete$X324_D0
LI_modules_complete$D7.D0_mean <- rowMeans(LI_modules_complete[,51:58])
LI_modules_D7.DO <- LI_modules_complete[,51:59]
write.csv2(LI_modules_D7.DO, "NK_BTM_enrichment_D7-D0.csv")
write.csv2(LI_modules_complete, "NK_BTM_enrichment_all_days.csv")
